@@ -11,12 +11,12 @@ class Dao(Component):
         return self.query().filter_by(**criterion).count()
 
     def exist(self, id=None, **criterion):
-        query = self.query().filter_by(**self._get_pk_criterion(id)) \
+        query = self.query().filter_by(**self.get_pk_criterion(id)) \
             if id is not None else self.query().filter_by(**criterion)
         return query.scalar() is not None
 
     def get(self, id=None, **criterion):
-        return self.query().filter_by(**self._get_pk_criterion(id)).first() \
+        return self.query().filter_by(**self.get_pk_criterion(id)).first() \
             if id is not None else self.query().filter_by(**criterion).first()
 
     def get_all(self, order=(), **criterion):
@@ -45,9 +45,9 @@ class Dao(Component):
         if len(criterion) > 0:
             self.query().filter_by(**criterion).update(obj if isinstance(obj, dict) else obj.to_dict())
         elif isinstance(obj, dict):
-            self.query().filter_by(**self._get_pk_criterion_by_object(obj)).update(obj)
+            self.query().filter_by(**self.get_pk_criterion_by_object(obj)).update(obj)
         else:
-            self._merge(obj)
+            self.merge(obj)
 
     @transactional()
     def delete(self, obj=None, **criterion):
@@ -55,32 +55,32 @@ class Dao(Component):
             self.query().filter_by(**criterion).delete()
         elif obj is not None:
             if isinstance(obj, (int, float)) or isinstance(obj, tuple):
-                self.query().filter_by(**self._get_pk_criterion_by_object(obj)).delete()
+                self.query().filter_by(**self.get_pk_criterion(obj)).delete()
             else:
                 session.delete(obj)
 
     def delete_all(self):
         self.query().delete()
 
-    def _begin(self, subtransactions=True, nested=False):
+    def begin(self, subtransactions=True, nested=False):
         session.begin(subtransactions=subtransactions, nested=nested)
 
-    def _begin_nested(self):
+    def begin_nested(self):
         session.begin_nested()
 
-    def _flush(self, objs):
+    def flush(self, objs):
         session.flush(objs)
 
-    def _merge(self, obj):
+    def merge(self, obj):
         return session.merge(obj)
 
-    def _commit(self):
+    def commit(self):
         session.commit()
 
-    def _rollback(self):
+    def rollback(self):
         session.rollback()
 
-    def _get_pk_criterion(self, id):
+    def get_pk_criterion(self, id):
         if isinstance(id, (int, float)):
             id = (id,)
 
@@ -90,7 +90,7 @@ class Dao(Component):
 
         return criterion
 
-    def _get_pk_criterion_by_object(self, obj):
+    def get_pk_criterion_by_object(self, obj):
         criterion = {}
         for idx, pk in enumerate(self.model.__mapper__.primary_key):
             criterion[pk.name] = obj[pk.name]
